==> haskell-hedgehog-1.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 1.0
id: hedgehog-1.0-Kvqh3KVyCJh9a85VQ4cjTV
key: hedgehog-1.0-Kvqh3KVyCJh9a85VQ4cjTV
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.
    .
    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.
    .
    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.
category: Testing
abi: 8dfeef101aa4b2f8099815306afa35d4
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hedgehog-1.0
hs-libraries: HShedgehog-1.0-Kvqh3KVyCJh9a85VQ4cjTV
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2
    concurrent-output-1.10.10-JWiJIHPaxcV2Cnnfh2Lilz containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    lifted-async-0.10.0.4-3pBM9jNFjmNHLheVP2ty89
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wl-pprint-annotated-0.1.0.1-15NaI63Tavn9BweNGcXZhU
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-1.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 1.0
id: hedgehog-1.0-K4ROqTohiCx2mhv3pNMVep
key: hedgehog-1.0-K4ROqTohiCx2mhv3pNMVep
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.
    .
    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.
    .
    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.
category: Testing
abi: 70e5595c04226bc43b7a299b52d61454
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hedgehog-1.0
hs-libraries: HShedgehog-1.0-K4ROqTohiCx2mhv3pNMVep
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2
    concurrent-output-1.10.10-JWiJIHPaxcV2Cnnfh2Lilz containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    lifted-async-0.10.0.4-Ca5EALnJ7enGTd0nw9JhDu
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wl-pprint-annotated-0.1.0.1-15NaI63Tavn9BweNGcXZhU
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
